@@ -13,7 +13,7 @@ mod io_vec_buf;
 pub use io_vec_buf::{IoVecBuf, IoVecBufMut, VecBuf};
 
 mod slice;
-pub use slice::Slice;
+pub use slice::{Slice, SliceMut};
 
 mod shared_buf;
 pub use shared_buf::{Shared, SharedBuf};
@@ -21,11 +21,5 @@ pub use shared_buf::{Shared, SharedBuf};
 pub(crate) fn deref(buf: &impl IoBuf) -> &[u8] {
     // Safety: the `IoBuf` trait is marked as unsafe and is expected to be
     // implemented correctly.
-    unsafe { std::slice::from_raw_parts(buf.stable_ptr(), buf.bytes_init()) }
-}
-
-pub(crate) fn deref_mut(buf: &mut impl IoBufMut) -> &mut [u8] {
-    // Safety: the `IoBufMut` trait is marked as unsafe and is expected to be
-    // implemented correct.
-    unsafe { std::slice::from_raw_parts_mut(buf.stable_mut_ptr(), buf.bytes_init()) }
+    unsafe { std::slice::from_raw_parts(buf.read_ptr(), buf.bytes_init()) }
 }
