@@ -16,7 +16,7 @@ pub trait AsyncReadRentExt<T: 'static> {
 
 impl<A, T> AsyncReadRentExt<T> for A
 where
-    A: AsyncReadRent,
+    A: AsyncReadRent + ?Sized,
     T: 'static + IoBufMut,
 {
     type Future<'a>
@@ -29,16 +29,21 @@ where
             let len = buf.bytes_total();
             let mut read = 0;
             while read < len {
-                let slice = buf.slice(read..len);
-                let (r, slice_) = self.read(slice).await;
-                buf = slice_.into_inner();
-                match r {
-                    Ok(r) => {
-                        read += r;
-                        if r == 0 {
-                            return (Err(std::io::ErrorKind::UnexpectedEof.into()), buf);
-                        }
+                let slice = unsafe { buf.slice_mut_unchecked(read..len) };
+                let (res, slice) = self.read(slice).await;
+                buf = slice.into_inner();
+                match res {
+                    Ok(0) => {
+                        return (
+                            Err(std::io::Error::new(
+                                std::io::ErrorKind::UnexpectedEof,
+                                "failed to fill whole buffer",
+                            )),
+                            buf,
+                        )
                     }
+                    Ok(n) => read += n,
+                    Err(ref e) if e.kind() == std::io::ErrorKind::Interrupted => {}
                     Err(e) => return (Err(e), buf),
                 }
             }
